@@ -19,8 +19,8 @@ file_dir = str(__file__).replace(str(__file__).split("/")[-1], "")
 
 
 class launchtest:
-
     def __init__(self, package, video_screen=1, run_times=10, ios="http://localhost:8100"):
+        print("12345")
         self.screen = video_screen
         self.times = run_times
         self.ios_host = ios
@@ -29,6 +29,7 @@ class launchtest:
     def start_video(self, video_path):
         global process
         command_linux = f"ffmpeg -f avfoundation  -video_device_index {self.screen} -i ':' {video_path}"
+        print(command_linux)
         process = subprocess.Popen(command_linux, shell=True)
 
     def pause_video_recording(self):
@@ -188,7 +189,8 @@ class launchtest:
         for x in range(0, self.times):
             # start_time = str(datetime.datetime.now()).replace(" ", "_")
             file_dir = str(__file__).replace(str(__file__).split("/")[-1], "")
-            video_path = file_dir + f"/recorded_videos/{device_name}/video/video_{device_name}.mkv"
+            start_time = str(datetime.datetime.now()).replace(" ", "_")
+            video_path = file_dir + f"/recorded_videos/{device_name}/video/video_{start_time}.mkv"
             time.sleep(5)
             self.start_video(video_path)
             time.sleep(5)
@@ -231,13 +233,23 @@ class launchtest:
     def help(self):
         print("Check screen devices command: ffmpeg -f avfoundation -list_devices true -i "" ")
         print(f"Belt.launchtest('', video_screen=3, run_times=1).launch_curve('android', '380x780+1450+150')")
+        print("convert 1.jpg -crop 393x829+20+80 2.jpg" "393x829 is area of device, 20+80 is start location of screen")
+        print("********Device information:********")
+        try:
+            print(wda.Client(self.ios_host).info)
+        except:
+            print(u2.connect().info)
 
 
 if __name__ == '__main__':
     # launchtest("").test_location("380x780+1450+150")
     # launchtest("").test_location("750x1600+2700+380")
     # launchtest("").show("sdk_gphone_x86", 10)
-    launchtest("com.disney.shanghaidisneyland_goo", video_screen=3, run_times=1).launch_curve("android", "380x780+0+150")
+    # launchtest("com.disney.shanghaidisneyland_goo", video_screen=3, run_times=1).help()
+    # launchtest("com.disney.shanghaidisneyland_goo", video_screen=3, run_times=10).launch_curve("android", "384x792+20+100", different_allow=15)
+    # launchtest("com.disney.shanghaidisneyland.dev", video_screen=3, run_times=10).cut_video("iPhone", "450x950+20+80", 15)
+    launchtest("com.disney.shanghaidisneyland.dev", video_screen=3, run_times=10).launch_curve("ios", "450x950+20+80", different_allow=15)
+    # launchtest("com.disney.shanghaidisneyland_goo", video_screen=3, run_times=1).launch_curve("android", "393x829+20+80", different_allow=15)
     # parser = argparse.ArgumentParser()
     # parser.add_argument("-os", "--operation_system", default=1, type=int,
     #                     help="Device OS Type, Only Support [1]: IOS & [2]: Android."
